<?php

   /**
    * @file
    * Module admin page callbacks.
    */
   /**
    * Implements the settings page.
    * @return
    *   The form structure.
    */
   function kerberos_authentication_admin_settings() {
      $options_login_process = array(
         KERBEROS_AUTHENTICATION_AUTH_MIXED      => t( 'Mixed mode. The Kerberos authentication is performed only if Drupal authentication fails' ),
         KERBEROS_AUTHENTICATION_AUTH_EXCLUSIVED => t( 'Kerberos only' )
      );
      $options_login_conflict = array(
         KERBEROS_AUTHENTICATION_CONFLICT_LOG     => t( 'Disallow login and log the conflict' ),
         KERBEROS_AUTHENTICATION_CONFLICT_RESOLVE => t( 'Associate local account with the Kerberos entry' )
      );
      $form['system-options'] = array(
         '#type'        => 'fieldset',
         '#title'       => t( 'Authentication mode' ),
         '#description' => t( '<strong>NOTE:</strong> These settings have no effect on Drupal user with uid 1. The admin account never uses Kerberos.' ),
         '#collapsible' => TRUE,
         '#collapsed'   => FALSE,
      );
      $form['system-options']['kerberos_authentication_login_process'] = array(
         '#type'          => 'radios',
         '#title'         => t( 'Choose authentication mode' ),
         '#description'   => t( 'Pick the mode based on the types of user accounts and other configuration decisions. If <i>Kerberos only</i> option is activated some UI modications will be applied.' ),
         '#default_value' => KERBEROS_AUTHENTICATION_LOGIN_PROCESS,
         '#options'       => $options_login_process,
         '#required'      => TRUE,
      );
      $form['system-options']['kerberos_authentication_login_conflict'] = array(
         '#type'          => 'radios',
         '#title'         => t( 'Choose user conflict resolve procedure' ),
         '#description'   => t( 'Pick what should be done if the local Drupal account already exists with the same login name.' ),
         '#default_value' => KERBEROS_AUTHENTICATION_LOGIN_CONFLICT,
         '#options'       => $options_login_conflict,
         '#required'      => TRUE,
      );
      $form['realms'] = array(
         '#type'        => 'fieldset',
         '#title'       => t( 'Kerberos Realms' ),
         '#collapsible' => TRUE,
         '#collapsed'   => FALSE,
      );
      $form['realms']['kerberos_authentication_realms'] = array(
         '#type'          => 'textarea',
         '#title'         => 'Kerberos Realms',
         '#description'   => t( 'List Kerberos realms, one per line, in the order that they should be tried during authentication.' ),
         '#default_value' => variable_get( "kerberos_authentication_realms", "" ),
         '#required'      => TRUE,
      );
      $form['security-options'] = array(
         '#type'        => 'fieldset',
         '#title'       => t( 'Security Options' ),
         '#collapsible' => TRUE,
         '#collapsed'   => TRUE,
      );
      $form['security-options']['kerberos_authentication_forget_passwords'] = array(
         '#type'          => 'checkbox',
         '#title'         => t( 'Do not store users\' passwords during sessions' ),
         '#default_value' => KERBEROS_AUTHENTICATION_FORGET_PASSWORDS,
      );
      $form['security-options']['kerberos_authentication_sync_passwords'] = array(
         '#type'          => 'checkbox',
         '#title'         => t( 'Sync Kerberos password with the Drupal password' ),
         '#default_value' => KERBEROS_AUTHENTICATION_SYNC_PASSWORDS,
         '#description'   => t( 'If checked, then Kerberos and Drupal passwords will be syncronized. This might be useful if some other modules need to authenticate against the user password hash stored in Drupal and works only in Mixed mode. It might introduce security issues in the Mixed mode since after deletion of the Kerberos principle user still be able to login to Drupal with his password. If unsure, leave this unchecked.' ),
      );
      $form['submit'] = array(
         '#type'  => 'submit',
         '#value' => t( 'Save configuration' ),
      );
      $form['reset'] = array(
         '#type'  => 'submit',
         '#value' => t( 'Reset to defaults' ),
      );
      return $form;
   }

   /**
    * Submit hook for the settings form.
    */
   function kerberos_authentication_admin_settings_submit($form, &$form_state) {
      $op = $form_state['clicked_button']['#value'];
      $values = $form_state['values'];
      switch ( $op ) {
         case t( 'Save configuration' ):
            variable_set( 'kerberos_authentication_login_process', $values['kerberos_authentication_login_process'] );
            variable_set( 'kerberos_authentication_login_conflict', $values['kerberos_authentication_login_conflict'] );
            variable_set( 'kerberos_authentication_forget_passwords', $values['kerberos_authentication_forget_passwords'] );
            variable_set( 'kerberos_authentication_sync_passwords', $values['kerberos_authentication_sync_passwords'] );
            variable_set( 'kerberos_authentication_realms', $values['kerberos_authentication_realms'] );
            drupal_set_message( t( 'The configuration options have been saved.' ) );
            break;
         case t( 'Reset to defaults' ):
            variable_del( 'kerberos_authentication_login_process' );
            variable_del( 'kerberos_authentication_login_conflict' );
            variable_del( 'kerberos_authentication_forget_passwords' );
            variable_del( 'kerberos_authentication_sync_passwords' );
            variable_del( 'kerberos_authentication_realms' );
            drupal_set_message( t( 'The configuration options have been reset to their default values.' ) );
            break;
      }
   }

